@@ -33,10 +33,14 @@ class RequestLoggingMiddleware(BaseHTTPMiddleware):
         # Get request details
         method = request.method
         path = request.url.path
+        query_params = str(request.url.query) if request.url.query else ""
         client_host = request.client.host if request.client else "unknown"
         
+        # Build URL with query params if present
+        full_path = f"{path}?{query_params}" if query_params else path
+        
         # Log request
-        logger.info(f"[{request_id}] 📨 {method} {path} - Client: {client_host}")
+        logger.info(f"[{request_id}] 📨 {method} {full_path} - Client: {client_host}")
         
         # Get request headers (excluding sensitive ones)
         safe_headers = {}
@@ -57,7 +61,7 @@ class RequestLoggingMiddleware(BaseHTTPMiddleware):
             
             # Log response
             status_emoji = "✅" if 200 <= response.status_code < 300 else "❌" if response.status_code >= 400 else "⚠️"
-            logger.info(f"[{request_id}] {status_emoji} {method} {path} - Status: {response.status_code} - Time: {process_time:.3f}s")
+            logger.info(f"[{request_id}] {status_emoji} {method} {full_path} - Status: {response.status_code} - Time: {process_time:.3f}s")
             
             # Add custom headers
             response.headers["X-Process-Time"] = str(process_time)
@@ -68,7 +72,7 @@ class RequestLoggingMiddleware(BaseHTTPMiddleware):
         except Exception as e:
             # Log error
             process_time = time.time() - start_time
-            logger.error(f"[{request_id}] ❌ {method} {path} - Error: {str(e)} - Time: {process_time:.3f}s")
+            logger.error(f"[{request_id}] ❌ {method} {full_path} - Error: {str(e)} - Time: {process_time:.3f}s")
             raise
 
 
@@ -79,9 +83,8 @@ class JSONParsingMiddleware(BaseHTTPMiddleware):
     """
     
     async def dispatch(self, request: Request, call_next: Callable) -> Response:
-        # Only apply to POST/PUT/PATCH requests to /api/v1/agent endpoints
+        # Only apply to POST/PUT/PATCH requests with JSON content type
         if (request.method in ["POST", "PUT", "PATCH"] and 
-            "/api/v1/agent" in request.url.path and
             request.headers.get("content-type", "").startswith("application/json")):
             
             try:
@@ -196,22 +199,23 @@ class JSONParsingMiddleware(BaseHTTPMiddleware):
         """
         Clean content string for use in JSON.
         """
-        # Remove or escape all special characters
+        # First handle already escaped characters
         result = content
-        # Escape newlines
-        result = result.replace('\n', '\\n')
-        result = result.replace('\r', '\\r')
-        # Escape tabs 
-        result = result.replace('\t', '\\t')
-        # Escape quotes
-        result = result.replace('"', '\\"')
-        # Fix any double escapes that might have been created
-        result = result.replace('\\\\n', '\\n')
-        result = result.replace('\\\\r', '\\r')
-        result = result.replace('\\\\t', '\\t')
-        result = result.replace('\\\\"', '\\"')
+        
+        # Replace backslashes that aren't part of escape sequences
+        # This regex looks for backslashes not followed by valid escape chars
+        import re
+        result = re.sub(r'\\(?!["\\/bfnrt])', r'\\\\', result)
+        
+        # Now escape unescaped special characters
+        # But be careful not to double-escape
+        result = re.sub(r'(?<!\\)"', r'\\"', result)
+        result = re.sub(r'(?<!\\)\n', r'\\n', result)
+        result = re.sub(r'(?<!\\)\r', r'\\r', result)
+        result = re.sub(r'(?<!\\)\t', r'\\t', result)
+        
         # Remove other control characters
-        result = ''.join(c if ord(c) >= 32 or c in ['\\n', '\\r', '\\t'] else ' ' for c in result)
+        result = ''.join(c if ord(c) >= 32 or c in ['\n', '\r', '\t'] else ' ' for c in result)
         
         return result
     
