@@ -217,6 +217,10 @@ def create_app() -> FastAPI:
     # Set up lifespan context manager
     @asynccontextmanager
     async def lifespan(app: FastAPI):
+        # Log version information
+        logger.info(f"🚀 Starting Automagik API v{SERVICE_INFO['version']}")
+        logger.info(f"📦 Service: {SERVICE_INFO['name']} - {SERVICE_INFO['description']}")
+        
         # Initialize database if needed
         # The database needs to be available first before any agent operations
         try:
@@ -612,5 +616,6 @@ if __name__ == "__main__":
         host=args.host,
         port=args.port,
         reload=args.reload,
-        timeout_graceful_shutdown=5
+        timeout_graceful_shutdown=5,
+        access_log=False  # Disable Uvicorn access logging since we have custom RequestLoggingMiddleware
     )
